==> open-xchange-usm_6.18.0.0.orig.tar.gz: open-xchange-usm-6.18.0.0/com.openexchange.usm.syncml/src/com/openexchange/usm/syncml/elements/SimpleElements.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.syncml.elements;

public class SimpleElements {
	public final static String ARCHIVE = "Archive";
	public final static String CMD = "Cmd";
	public final static String CMD_ID = "CmdID";
	public final static String CMD_REF = "CmdRef";
	public final static String FINAL = "Final";
	public final static String LANG = "Lang";
	public final static String LOC_NAME = "LocName";
	public final static String LOC_URI = "LocURI";
	public final static String MSG_ID = "MsgID";
	public final static String MSG_REF = "MsgRef";
	public final static String NO_RESP = "NoResp";
	public final static String NO_RESULTS = "NoResults";
	public static final String NUMBER_OF_CHANGES = "NumberOfChanges";
	public final static String RESP_URI = "RespURI";
	public final static String SESSION_ID = "SessionID";
	public final static String SFT_DEL = "SftDel";
	public final static String SOURCE_REF = "SourceRef";
	public final static String TARGET_REF = "TargetRef";
	public final static String VER_DTD = "VerDTD";
	public final static String VER_PROTO = "VerProto";
}

==> open-xchange-usm_6.20.8.0.orig.tar.gz: open-xchange-usm-6.20.8.0/com.openexchange.usm.syncml/src/com/openexchange/usm/syncml/elements/SimpleElements.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.syncml.elements;

public class SimpleElements {
	public static final String ARCHIVE = "Archive";
	public static final String CMD = "Cmd";
	public static final String CMD_ID = "CmdID";
	public static final String CMD_REF = "CmdRef";
	public static final String FINAL = "Final";
	public static final String LANG = "Lang";
	public static final String LOC_NAME = "LocName";
	public static final String LOC_URI = "LocURI";
	public static final String MSG_ID = "MsgID";
	public static final String MSG_REF = "MsgRef";
	public static final String NO_RESP = "NoResp";
	public static final String NO_RESULTS = "NoResults";
	public static final String NUMBER_OF_CHANGES = "NumberOfChanges";
	public static final String RESP_URI = "RespURI";
	public static final String SESSION_ID = "SessionID";
	public static final String SFT_DEL = "SftDel";
	public static final String SOURCE_REF = "SourceRef";
	public static final String TARGET_REF = "TargetRef";
	public static final String VER_DTD = "VerDTD";
	public static final String VER_PROTO = "VerProto";
}
